@@ -19,7 +19,7 @@ from phi.utils.log import logger, set_log_level_to_debug
 from phi.workspace.ws_enums import (
     WorkspaceEnv,
     WorkspaceStarterTemplate,
-    WorkspaceInfra,
+    WorkspaceConfigType,
 )
 
 ws_app = typer.Typer(
@@ -219,7 +219,7 @@ def setup(
 def up(
     ws_filter: Optional[str] = typer.Argument(
         None,
-        help="Filter the resources to deploy. Format - ENV:NAME:TYPE:INFRA",
+        help="Filter the resources to deploy. Format - ENV:NAME:TYPE:CONFIG",
         metavar="[filter]",
     ),
     env_filter: Optional[str] = typer.Option(
@@ -231,13 +231,13 @@ def up(
             WorkspaceEnv.values_list()
         ),
     ),
-    infra_filter: Optional[str] = typer.Option(
+    config_filter: Optional[str] = typer.Option(
         None,
-        "-i",
-        "--infra",
+        "-c",
+        "--config",
         metavar="",
-        help="Filter the infrastructure to deploy. Available Options: {}".format(
-            WorkspaceInfra.values_list()
+        help="Filter the config to deploy. Available Options: {}".format(
+            WorkspaceConfigType.values_list()
         ),
     ),
     name_filter: Optional[str] = typer.Option(
@@ -268,7 +268,7 @@ def up(
     Deploys the active workspace.
     Filters can be used to limit deployment by
         - env (dev, stg, prd)
-        - infra (docker, aws, k8s)
+        - config (docker, aws, k8s)
         - Resource Name
         - Resource Type
     \b
@@ -301,13 +301,13 @@ def up(
         return
 
     target_env_str: Optional[str] = None
-    target_infra_str: Optional[str] = None
+    target_config_str: Optional[str] = None
     target_env: Optional[WorkspaceEnv] = None
-    target_infra: Optional[WorkspaceInfra] = None
+    target_config: Optional[WorkspaceConfigType] = None
     target_name: Optional[str] = None
     target_type: Optional[str] = None
 
-    # derive env/infra/name/type from ws_filter
+    # derive env/config/name/type from ws_filter
     if ws_filter is not None:
         if not isinstance(ws_filter, str):
             raise TypeError(
@@ -323,23 +323,23 @@ def up(
         if num_filters >= 3:
             target_type = filters[2]
         if num_filters >= 4:
-            target_infra_str = filters[3]
+            target_config_str = filters[3]
 
-    # derive env/infra/name/type from command options
+    # derive env/config/name/type from command options
     if target_env_str is None:
         target_env_str = env_filter
-    if target_infra_str is None:
-        target_infra_str = infra_filter
+    if target_config_str is None:
+        target_config_str = config_filter
     if target_name is None:
         target_name = name_filter
     if target_type is None:
         target_type = type_filter
 
-    # derive env/infra/name/type from defaults
+    # derive env/config/name/type from defaults
     if target_env_str is None:
         target_env_str = active_ws_data.ws_config.default_env
-    if target_infra_str is None:
-        target_infra_str = active_ws_data.ws_config.default_infra
+    if target_config_str is None:
+        target_config_str = active_ws_data.ws_config.default_config
 
     if target_env_str is not None:
         if target_env_str.lower() not in WorkspaceEnv.values_list():
@@ -352,27 +352,27 @@ def up(
             WorkspaceEnv.from_str(target_env_str),
         )
 
-    if target_infra_str is not None:
-        if target_infra_str.lower() not in WorkspaceInfra.values_list():
+    if target_config_str is not None:
+        if target_config_str.lower() not in WorkspaceConfigType.values_list():
             print_error(
-                f"{target_infra_str} is not supported, please choose from: {WorkspaceInfra.values_list()}"
+                f"{target_config_str} is not supported, please choose from: {WorkspaceConfigType.values_list()}"
             )
             return
-        target_infra = cast(
-            WorkspaceInfra,
-            WorkspaceInfra.from_str(target_infra_str),
+        target_config = cast(
+            WorkspaceConfigType,
+            WorkspaceConfigType.from_str(target_config_str),
         )
 
     logger.debug("Deploying workspace")
     logger.debug(f"\ttarget_env  : {target_env}")
-    logger.debug(f"\ttarget_infra: {target_infra}")
+    logger.debug(f"\ttarget_config: {target_config}")
     logger.debug(f"\ttarget_name : {target_name}")
     logger.debug(f"\ttarget_type : {target_type}")
     print_heading("Deploying workspace: {}\n".format(active_ws_data.ws_name))
     deploy_workspace(
         ws_data=active_ws_data,
         target_env=target_env,
-        target_infra=target_infra,
+        target_config=target_config,
         target_name=target_name,
         target_type=target_type,
         dry_run=dry_run,
@@ -383,7 +383,7 @@ def up(
 def down(
     ws_filter: Optional[str] = typer.Argument(
         None,
-        help="Filter the resources to shut down. Format - ENV:NAME:TYPE:INFRA",
+        help="Filter the resources to shut down. Format - ENV:NAME:TYPE:CONFIG",
         metavar="[filter]",
     ),
     env_filter: str = typer.Option(
@@ -395,13 +395,13 @@ def down(
             WorkspaceEnv.values_list()
         ),
     ),
-    infra_filter: str = typer.Option(
+    config_filter: str = typer.Option(
         None,
-        "-i",
-        "--infra",
+        "-c",
+        "--config",
         metavar="",
-        help="Filter the infrastructure to shut down. Available Options: {}".format(
-            WorkspaceInfra.values_list()
+        help="Filter the config to shut down. Available Options: {}".format(
+            WorkspaceConfigType.values_list()
         ),
     ),
     name_filter: Optional[str] = typer.Option(
@@ -455,13 +455,13 @@ def down(
         return
 
     target_env_str: Optional[str] = None
-    target_infra_str: Optional[str] = None
+    target_config_str: Optional[str] = None
     target_env: Optional[WorkspaceEnv] = None
-    target_infra: Optional[WorkspaceInfra] = None
+    target_config: Optional[WorkspaceConfigType] = None
     target_name: Optional[str] = None
     target_type: Optional[str] = None
 
-    # derive env/infra/name/type from ws_filter
+    # derive env/config/name/type from ws_filter
     if ws_filter is not None:
         if not isinstance(ws_filter, str):
             raise TypeError(
@@ -477,23 +477,23 @@ def down(
         if num_filters >= 3:
             target_type = filters[2]
         if num_filters >= 4:
-            target_infra_str = filters[3]
+            target_config_str = filters[3]
 
-    # derive env/infra/name/type from command options
+    # derive env/config/name/type from command options
     if target_env_str is None:
         target_env_str = env_filter
-    if target_infra_str is None:
-        target_infra_str = infra_filter
+    if target_config_str is None:
+        target_config_str = config_filter
     if target_name is None:
         target_name = name_filter
     if target_type is None:
         target_type = type_filter
 
-    # derive env/infra/name/type from defaults
+    # derive env/config/name/type from defaults
     if target_env_str is None:
         target_env_str = active_ws_data.ws_config.default_env
-    if target_infra_str is None:
-        target_infra_str = active_ws_data.ws_config.default_infra
+    if target_config_str is None:
+        target_config_str = active_ws_data.ws_config.default_config
 
     if target_env_str is not None:
         if target_env_str.lower() not in WorkspaceEnv.values_list():
@@ -506,27 +506,191 @@ def down(
             WorkspaceEnv.from_str(target_env_str),
         )
 
-    if target_infra_str is not None:
-        if target_infra_str.lower() not in WorkspaceInfra.values_list():
+    if target_config_str is not None:
+        if target_config_str.lower() not in WorkspaceConfigType.values_list():
             print_error(
-                f"{target_infra_str} is not supported, please choose from: {WorkspaceInfra.values_list()}"
+                f"{target_config_str} is not supported, please choose from: {WorkspaceConfigType.values_list()}"
             )
             return
-        target_infra = cast(
-            WorkspaceInfra,
-            WorkspaceInfra.from_str(target_infra_str),
+        target_config = cast(
+            WorkspaceConfigType,
+            WorkspaceConfigType.from_str(target_config_str),
         )
 
     logger.debug("Shutting down workspace")
     logger.debug(f"\ttarget_env: {target_env}")
-    logger.debug(f"\ttarget_infra: {target_infra}")
+    logger.debug(f"\ttarget_config: {target_config}")
     logger.debug(f"\ttarget_name: {target_name}")
     logger.debug(f"\ttarget_type: {target_type}")
     print_heading("Shutdown workspace: {}\n".format(active_ws_data.ws_name))
     shutdown_workspace(
         ws_data=active_ws_data,
         target_env=target_env,
-        target_infra=target_infra,
+        target_config=target_config,
+        target_name=target_name,
+        target_type=target_type,
+        dry_run=dry_run,
+    )
+
+
+@ws_app.command(short_help="Update your active workspace")
+def patch(
+    ws_filter: Optional[str] = typer.Argument(
+        None,
+        help="Filter the resources to patch. Format - ENV:NAME:TYPE:CONFIG",
+        metavar="[filter]",
+    ),
+    env_filter: str = typer.Option(
+        None,
+        "-e",
+        "--env",
+        metavar="",
+        help="Filter the environment to patch. Available Options: {}".format(
+            WorkspaceEnv.values_list()
+        ),
+    ),
+    config_filter: str = typer.Option(
+        None,
+        "-c",
+        "--config",
+        metavar="",
+        help="Filter the config to patch. Available Options: {}".format(
+            WorkspaceConfigType.values_list()
+        ),
+    ),
+    name_filter: Optional[str] = typer.Option(
+        None, "-n", "--name", metavar="", help="Filter using resource name"
+    ),
+    type_filter: Optional[str] = typer.Option(
+        None,
+        "-t",
+        "--type",
+        metavar="",
+        help="Filter using resource type",
+    ),
+    dry_run: bool = typer.Option(
+        False,
+        "-dr",
+        "--dry-run",
+        help="Print which resources will be patched and exit.",
+    ),
+    print_debug_log: bool = typer.Option(
+        False,
+        "-d",
+        "--debug",
+        help="Print debug logs.",
+    ),
+):
+    """
+    \b
+    Patch the active workspace.
+    Filters can be used to limit patching by
+        - env (dev, stg, prd)
+        - config (docker, aws, k8s)
+        - Resource Name
+        - Resource Type
+    \b
+    Filters can be provided as a single argument or using multiple options.
+    Examples:
+    \b
+    $ `phi ws patch`           -> Patch default resources
+    $ `phi ws patch dev`       -> Patch all dev resources
+    $ `phi ws patch prd`       -> Patch all prd resources
+    $ `phi ws patch prd:::aws` -> Patch all prd aws resources
+    $ `phi ws patch prd:s3`    -> Patch prd resources with name s3
+    """
+    from phi.conf.phi_conf import PhiConf, PhiWsData
+    from phi.workspace.ws_operator import patch_workspace
+
+    if print_debug_log:
+        set_log_level_to_debug()
+
+    phi_conf: Optional[PhiConf] = PhiConf.get_saved_conf()
+    if not phi_conf:
+        print_conf_not_available_msg()
+        return
+
+    active_ws_data: Optional[PhiWsData] = phi_conf.get_active_ws_data(refresh=True)
+    if active_ws_data is None:
+        print_active_workspace_not_available()
+        avl_ws = phi_conf.available_ws
+        if avl_ws:
+            print_available_workspaces(avl_ws)
+        return
+
+    target_env_str: Optional[str] = None
+    target_config_str: Optional[str] = None
+    target_env: Optional[WorkspaceEnv] = None
+    target_config: Optional[WorkspaceConfigType] = None
+    target_name: Optional[str] = None
+    target_type: Optional[str] = None
+
+    # derive env/config/name/type from ws_filter
+    if ws_filter is not None:
+        if not isinstance(ws_filter, str):
+            raise TypeError(
+                f"Invalid workspace filter. Expected: str, Received: {type(ws_filter)}"
+            )
+        filters = ws_filter.split(":")
+        # logger.debug(f"filters: {filters}")
+        num_filters = len(filters)
+        if num_filters >= 1:
+            target_env_str = filters[0]
+        if num_filters >= 2:
+            target_name = filters[1]
+        if num_filters >= 3:
+            target_type = filters[2]
+        if num_filters >= 4:
+            target_config_str = filters[3]
+
+    # derive env/config/name/type from command options
+    if target_env_str is None:
+        target_env_str = env_filter
+    if target_config_str is None:
+        target_config_str = config_filter
+    if target_name is None:
+        target_name = name_filter
+    if target_type is None:
+        target_type = type_filter
+
+    # derive env/config/name/type from defaults
+    if target_env_str is None:
+        target_env_str = active_ws_data.ws_config.default_env
+    if target_config_str is None:
+        target_config_str = active_ws_data.ws_config.default_config
+
+    if target_env_str is not None:
+        if target_env_str.lower() not in WorkspaceEnv.values_list():
+            print_error(
+                f"{target_env_str} is not supported, please choose from: {WorkspaceEnv.values_list()}"
+            )
+            return
+        target_env = cast(
+            WorkspaceEnv,
+            WorkspaceEnv.from_str(target_env_str),
+        )
+
+    if target_config_str is not None:
+        if target_config_str.lower() not in WorkspaceConfigType.values_list():
+            print_error(
+                f"{target_config_str} is not supported, please choose from: {WorkspaceConfigType.values_list()}"
+            )
+            return
+        target_config = cast(
+            WorkspaceConfigType,
+            WorkspaceConfigType.from_str(target_config_str),
+        )
+
+    logger.debug("Patching workspace")
+    logger.debug(f"\ttarget_env: {target_env}")
+    logger.debug(f"\ttarget_config: {target_config}")
+    logger.debug(f"\ttarget_name: {target_name}")
+    logger.debug(f"\ttarget_type: {target_type}")
+    print_heading("Patching workspace: {}\n".format(active_ws_data.ws_name))
+    patch_workspace(
+        ws_data=active_ws_data,
+        target_env=target_env,
+        target_config=target_config,
         target_name=target_name,
         target_type=target_type,
         dry_run=dry_run,
@@ -537,7 +701,7 @@ def down(
 def restart(
     ws_filter: Optional[str] = typer.Argument(
         None,
-        help="Filter the resources to restart. Format - ENV:NAME:TYPE:INFRA",
+        help="Filter the resources to restart. Format - ENV:NAME:TYPE:CONFIG",
         metavar="[filter]",
     ),
     env_filter: str = typer.Option(
@@ -549,13 +713,13 @@ def restart(
             WorkspaceEnv.values_list()
         ),
     ),
-    infra_filter: str = typer.Option(
+    config_filter: str = typer.Option(
         None,
         "-i",
-        "--infra",
+        "--config",
         metavar="",
-        help="Filter the infrastructure to restart. Available Options: {}".format(
-            WorkspaceInfra.values_list()
+        help="Filter the config to restart. Available Options: {}".format(
+            WorkspaceConfigType.values_list()
         ),
     ),
     name_filter: Optional[str] = typer.Option(
@@ -588,7 +752,7 @@ def restart(
     down(
         ws_filter=ws_filter,
         env_filter=env_filter,
-        infra_filter=infra_filter,
+        config_filter=config_filter,
         name_filter=name_filter,
         type_filter=type_filter,
         dry_run=False,
@@ -599,7 +763,7 @@ def restart(
     up(
         ws_filter=ws_filter,
         env_filter=env_filter,
-        infra_filter=infra_filter,
+        config_filter=config_filter,
         name_filter=name_filter,
         type_filter=type_filter,
         dry_run=False,
