@@ -330,7 +330,7 @@ def run_data_products_docker(
     docker_config: DockerConfig,
     target_app: Optional[str] = None,
 ) -> bool:
-    from phidata.app.databox import DataboxArgs, default_databox_name
+    from phidata.app.databox import Databox, DataboxArgs, default_databox_name
     from phidata.infra.docker.resource.types import (
         DockerResourceType,
         DockerContainer,
@@ -347,7 +347,7 @@ def run_data_products_docker(
     databox_app_name = target_app or docker_config.databox_name or default_databox_name
     logger.debug(f"Using App: {databox_app_name}")
     databox_app = docker_config.get_app_by_name(databox_app_name)
-    if databox_app is None:
+    if databox_app is None or not isinstance(databox_app, Databox):
         print_error("Databox not available")
         return False
     databox_app_args: Optional[Any] = databox_app.args
@@ -394,13 +394,14 @@ def run_data_products_docker(
     logger.debug(f"PathContext: {dp_path_context.json(indent=4)}")
 
     # Step 4: Get the container to run the DataProduct
+    databox_container_name = databox_app.get_container_name()
     databox_containers: Optional[
         List[DockerResourceType]
     ] = docker_manager.get_resources(
-        name_filter=databox_app_name, type_filter="DockerContainer"
+        name_filter=databox_container_name, type_filter="Container"
     )
-    if databox_containers is None:
-        logger.error(f"DockerContainer:{databox_app_name} not found")
+    if databox_containers is None or len(databox_containers) == 0:
+        logger.error(f"DockerContainer:{databox_container_name} not found")
         return False
     if len(databox_containers) > 1:
         print_info(
