@@ -373,9 +373,9 @@ def setup_workspace(ws_dir_path: Path) -> bool:
     ws_data: Optional[PhiWsData] = phi_conf.get_ws_data_by_path(ws_dir_path)
     if ws_data is None:
         # This happens if
+        # - The user is setting up an existing workspace
         # - the user ran `phi init -r` which erases the self._path_to_ws_data_map
-        # - OR the user is setting up a manual workspace
-        logger.debug(f"Could not find a workspace at path: {ws_dir_path}")
+        logger.debug(f"Could not find an existing workspace at path: {ws_dir_path}")
         # We'll try to parse this workspace using the workspace config
         # validate that a workspace config file exists
         __ws_config_file_path: Path = get_ws_config_file_path(ws_dir_path)
@@ -1021,11 +1021,12 @@ def set_workspace_as_active(ws_name: Optional[str], refresh: bool = True) -> boo
     print_heading(f"Setting workspace {new_active_ws_name} as active")
     if refresh:
         try:
-            refresh_success = phi_conf.refresh_ws_config(new_active_ws_name)
-            if not refresh_success:
-                print_warning("Could not refresh workspace config")
+            phi_conf.refresh_ws_config(new_active_ws_name)
         except WorkspaceConfigException as e:
-            print_info("Please fix the errors and try again")
+            print_error(
+                "Could not refresh workspace config, please fix errors and try again"
+            )
+            print_error(e)
             return False
 
     ######################################################
